#!/bin/sh

RepScript=`dirname $0`
RepCourant=`pwd`

usage()
{
	echo "The shutdown.sh script is used to shutdown Petals."
    echo "usage : shutdown.sh [-h|-y]"
    echo "     -h : prints the help message"
    echo "     -y : no confirmation is asked"
    exit 0;
}

######################
#   ENV VARIABLES
######################

echo "Setting Petals environment"

if [ ! -d "$JAVA_HOME" ]
then
        echo "The JAVA_HOME variable is not properly set. Please set it in your environment."
        exit 1
fi

if [ ! -d "$PETALS_HOME" ]
then
	PETALS_HOME="$RepCourant/$RepScript/.."
	export PETALS_HOME
fi

if [ ! -f "$PETALS_HOME/conf/server.properties" ]
then
	echo "The PETALS_HOME environment variable is not set correctly. Please set it in your environment with a correct value."
	exit 2
fi

PATH="$JAVA_HOME/bin:$PATH"
export PATH

CLASSPATH="$PETALS_HOME/bin/server.jar:$CLASSPATH"
export CLASSPATH

java -version
echo ""


######################
#   ARGUMENTS
######################

cd "$PETALS_HOME/bin"

Confirmed=false
while getopts :hv:yv options
do
        case ${options} in
                h)
                        usage
                        ;;
                y)
                        Confirmed=true
                        ;;
        esac
done

if [ "$Confirmed" = "false" ]
then
	echo "Are you sure to remove this PEtALS container from your PEtALS network (Y/n) ?"
	echo "    - all services assembly of this container will be undeployed,"
	echo "    - all components of this container will be uninstalled,"
	echo "    - this PEtALS container will be removed from the topology."
	read ANSWER
	if [ "$ANSWER" = "Y" ]
	then
		Confirmed=true
	fi
fi

Return=0
if [ "$Confirmed" = "true" ]
then
	java -Xmx1024m -jar server.jar shutdown
	Return=$?
else
	echo "Shutdown canceled."
fi

cd "$RepCourant"

if [ $Return != 0 ]
then
	exit 1
else
	exit 0
fi
