#!/bin/sh

RepScript=`dirname $0`
RepCourant=`pwd`

usage()
{
	echo "The startup.sh script is used to start Petals."
	echo "usage : startup.sh [-h|-?] [-D|C] [-E] [-P <profilerId>]"
	echo "     -h|? : prints the help message"
	echo "     -D : Petals is starting in daemon mode"
	echo "     -C : Petals is starting with command line"
	exit 0;
}


######################
#   ENV VARIABLES
######################

echo "Setting PEtALS environment"

if [ ! -d "$JAVA_HOME" ]
then
        echo "The JAVA_HOME variable is not properly set. Please set it in your environment."
        exit 1
fi

if [ ! -d "$PETALS_HOME" ]
then
	PETALS_HOME="$RepCourant/$RepScript/.."
	export PETALS_HOME
fi

if [ ! -f "$PETALS_HOME/conf/server.properties" ]
then
	echo "The PETALS_HOME environment variable is not set correctly. Please set it in your environment with a correct value."
	exit 2
fi

if [ ! -d "$PETALS_HOME/logs" ]
then
        mkdir "$PETALS_HOME/logs"
fi

PATH="$JAVA_HOME/bin:$PATH"
export PATH

LOG_FILE="$PETALS_HOME/logs/petals-out.log"

java -version
echo ""

######################
#   ARGUMENTS
######################

cd "$PETALS_HOME/bin"

DaemonMode=false
CommandLine=false
while getopts :hv:Dv:Cv:Ev options
do
        case ${options} in
                h)
                        usage
                        ;;
                C)
                        CommandLine=true
                        CLOption="-console"
                        ;;
                D)
                        DaemonMode=true
                        ;;
                ?)
			usage
                        ;;
        esac
done


if [ $CommandLine != false -a $DaemonMode != false ]
then
        echo "PEtALS Container can be started in daemon mode or with command line, but not the two at the same time."
        echo "Use -D or -C!"
        exit 1
fi



if [ $DaemonMode != false ]
then
        echo "PEtALS Container starting in daemon mode..."
        nohup java -Xmx1024m -server -jar server.jar start $CLOption 1>$LOG_FILE 2>>$LOG_FILE &
        Return=$?
else
        java -Xmx1024m -server -jar server.jar start $CLOption
        Return=$?
fi

cd "$RepCourant"

if [ $Return != 0 ]
then
	exit 1
else
	exit 0
fi
